"""Simple credential with token directly"""
from .base_credential import DaasBaseCredential


class SimpleCredential(DaasBaseCredential):
    """
    Simple credentials by passing token directly to daas client.
    """

    def __init__(self, token: str):
        self._token = token

    def get_token(self, **kwargs) -> str:
        return self._token



"""Basic credentials using username/password"""
import requests

from typing import Union, Dict

from .base_credential import DaasBaseCredential


class DaasBasicCredential(DaasBaseCredential):
    """Get token via basic authentification"""

    def __init__(
        self,
        username: str,
        password: str,
        token_endpoint: str,
    ) -> None:
        super().__init__()
        self._username = username
        self._password = password
        self._token_endpoint = token_endpoint

    def get_token(self, **kwargs) -> Union[str, None]:
        """
        return access token.
        """
        token = self._get_token()
        if "access_token" in token:
            return token["access_token"]

    def _get_token(self) -> Dict:
        """Get token from daas auth"""
        url = self._token_endpoint
        data = {
            "email": self._username,
            "password": self._password,
        }

        response = requests.post(url=url, data=data)

        return response.json()



from glob import glob
from os.path import basename
from os.path import splitext
from setuptools import setup, find_packages


__VERSION__ = "0.0.5"

setup(
    name="daas-service-sdk",
    version=__VERSION__,
    description="Daas Service SDK for Python",
    url="https://github.com/grasp-labs/daas-service-sdk-python",
    author="Grasp Labs",
    author_email="yuan@grasplabs.com",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    keywords="daas service sdk python",
    python_requires=">=3.7",
    packages=find_packages("src"),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("daas_service_sdk/*.py")],
    include_package_data=True,
    install_requires=["requests"],
    project_urls={
        "Issue Tracker": "https://github.com/grasp-labs/daas-service-sdk-python/issues",
    },
)



from abc import ABC, abstractmethod


class DaasBaseCredential(ABC):
    """
    Abstract base credential class for connecting with Daas service.
    Cannot be used directly.
    """

    @abstractmethod
    def get_token(self, **kwargs) -> str:
        """Get access token, trying to refresh if needed."""
